@@ -14,6 +14,7 @@
     along with Jellyfish.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <cstdlib>
 #include <new>
 #include <stdexcept>
 #include <vector>
@@ -21,6 +22,23 @@
 #include <assert.h>
 #include <jellyfish/rectangular_binary_matrix.hpp>
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#ifdef HAVE_POSIX_MEMALIGN
+inline int __mem_align(void** memptr, size_t alignement, size_t size) {
+  return posix_memalign(memptr, alignement, size);
+}
+#elif HAVE_ALIGNED_ALLOC
+inline int __mem_align(void** memptr, size_t alignment, size_t size) {
+  *memptr = aligned_alloc(alignment, size);
+  return memptr == NULL;
+}
+#else
+#error No function to allocate aligned memory
+#endif
+
 uint64_t *jellyfish::RectangularBinaryMatrix::alloc(unsigned int r, unsigned int c) {
   if(r > (sizeof(uint64_t) * 8) || r == 0 || c == 0) {
     std::ostringstream err;
@@ -31,8 +49,7 @@ uint64_t *jellyfish::RectangularBinaryMatrix::alloc(unsigned int r, unsigned int
   // Make sure the number of words allocated is a multiple of
   // 8. Necessary for loop unrolling of vector multiplication
   size_t alloc_columns = (c / 8 + (c % 8 != 0)) * 8;
-  //  if(posix_memalign(&mem, sizeof(uint64_t) * 2, alloc_columns * sizeof(uint64_t)))
-  if(!(mem = aligned_alloc(sizeof(uint64_t) * 2, alloc_columns * sizeof(uint64_t))))
+  if(__mem_align(&mem, sizeof(uint64_t) * 2, alloc_columns * sizeof(uint64_t)))
     throw std::bad_alloc();
   memset(mem, '\0', sizeof(uint64_t) * alloc_columns);
   return (uint64_t *)mem;
